@@ -1,5 +1,5 @@
 package List::Compare::Base::_Auxiliary;
-$VERSION = 0.47;
+$VERSION = 0.48;
 use Carp;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
@@ -9,7 +9,6 @@ use Carp;
     _calculate_array_seen_only
     _calculate_seen_only
     _calculate_intermediate
-    _calculate_xintersection_only
     _calculate_union_only
     _calculate_union_seen_only
     _calculate_hash_intersection
@@ -47,7 +46,6 @@ use Carp;
         _calculate_array_seen_only
         _calculate_seen_only
         _calculate_intermediate
-        _calculate_xintersection_only
         _calculate_union_only
         _calculate_union_seen_only
         _calculate_hash_intersection
@@ -226,27 +224,6 @@ sub _calculate_intermediate {
     return \%intermediate;
 }
 
-sub _calculate_xintersection_only {
-    my $aref = shift;
-    my (%xintersection);
-    for (my $i = 0; $i <= $#{$aref}; $i++) {
-        my %seenthis = ();
-        foreach my $h ( _list_builder($aref, $i) ) {
-            $seenthis{$h}++;
-        }
-        for (my $j = $i+1; $j <=$#{$aref}; $j++) {
-            my (%seenthat, %seenintersect);
-            my $ilabel = $i . '_' . $j;
-            $seenthat{$_}++ foreach ( _list_builder($aref, $j) );
-            foreach (keys %seenthat) {
-                $seenintersect{$_}++ if (exists $seenthis{$_});
-            }
-            $xintersection{$ilabel} = \%seenintersect;
-        }
-    }
-    return \%xintersection;
-}
-
 sub _calculate_union_only {
     my $aref = shift;
     my (%union);
@@ -750,8 +727,8 @@ List::Compare::Base::_Auxiliary - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.47 of List::Compare::Base::_Auxiliary.
-This version was released February 22 2015.
+This document refers to version 0.48 of List::Compare::Base::_Auxiliary.
+This version was released February 25 2015.
 
 =head1 SYNOPSIS
 
@@ -763,7 +740,7 @@ List::Compare::Functional.  They are not intended to be publicly callable.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare' or 'List-Compare' in your subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 22 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 25 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
