@@ -1,5 +1,5 @@
 package List::Compare::Functional;
-$VERSION = 0.47;
+$VERSION = 0.48;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
     get_intersection
@@ -352,18 +352,14 @@ sub is_LdisjointR {
 sub _is_LdisjointR_engine {
     my $testedref = pop(@_);
     my $seenrefsref = _calc_seen1(@_);
-    my $xintersectionref = _calculate_xintersection_only($seenrefsref);
-    my (@xdisjoint);
-    for (my $i = 0; $i <= @{$seenrefsref}; $i++) {
-        foreach (keys %{$xintersectionref}) {
-            my ($left, $right) = split /_/, $_;
-            $xdisjoint[$left][$right] = $xdisjoint[$right][$left] =
-                ! scalar(keys %{${$xintersectionref}{$_}}) ? 1 : 0;
+    my $disjoint = 1; # start out assuming disjoint status
+    OUTER: for my $k (keys %{$seenrefsref->[$testedref->[0]]}) {
+        if ($seenrefsref->[$testedref->[1]]->{$k}) {
+            $disjoint = 0;
+            last OUTER;
         }
-        $xdisjoint[$i][$i] = 0;
     }
-    my $disjoint_status = $xdisjoint[${$testedref}[1]][${$testedref}[0]];
-    return $disjoint_status;
+    return $disjoint;
 }
 
 sub print_subset_chart {
@@ -517,8 +513,8 @@ List::Compare::Functional - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.47 of List::Compare::Functional.
-This version was released February 22 2015.  The first released
+This document refers to version 0.48 of List::Compare::Functional.
+This version was released February 25 2015.  The first released
 version of List::Compare::Functional was v0.21.  Its version numbers
 are set to be consistent with the other parts of the List::Compare
 distribution.
@@ -1682,7 +1678,7 @@ James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare::Functional' or 'List-Compare-Functional' in your
 subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 22 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 25 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
